# md2jira

[![PyPI](https://img.shields.io/pypi/v/md2jira)](https://pypi.org/project/md2jira/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/md2jira)](https://www.python.org/downloads/)
[![GitHub last commit](https://img.shields.io/github/last-commit/daxartio/md2jira)](https://github.com/daxartio/md2jira)
[![GitHub stars](https://img.shields.io/github/stars/daxartio/md2jira?style=social)](https://github.com/daxartio/md2jira)

```
pip install md2jira
```

Also try `pandoc`

```
pandoc in.md -o out.txt --to jira
```

## Contributing

[Contributing](CONTRIBUTING.md)

## Get started

```
md2jira --help
```

This project was forked
